@@ -744,7 +744,8 @@ class Install(color_print):
             self.startTask(_("Preparing the system for reboot"))
             self.prepareBoot(self.targetDistr)
         self.endTask()
-        if self.askConfirm(_("Would you like to reboot your computer "
+        if self.clVars.Get('os_install_pxe') == "off" and \
+            self.askConfirm(_("Would you like to reboot your computer "
                              "now to complete the installation?"),
                                 default="no") == "yes":
             os.system("/sbin/reboot")
