@@ -62,6 +62,7 @@ class InstallInfo(CommonInfo):
 
     cl_migrate_root_pwd = String
     cl_migrate_data = Array(Array(String))
+    cl_install_home_crypt_set = Boolean
     cl_autologin = String
     os_install_net_fqdn = String
     os_install_net_data = Array(Array(String))
@@ -75,6 +76,7 @@ class InstallInfo(CommonInfo):
     os_install_x11_composite = Boolean
     os_install_fb_resolution = String
     os_install_grub_terminal = String
+    os_audio_default = String
 
     cl_autopartition_device = Array(String)
     cl_autopartition_scheme = Array(String)
@@ -139,8 +141,11 @@ class Wsdl:
                     'os_install_net_route_data',))
         dv.addGroup(_("Users"),
             normal=('cl_migrate_root_pwd','cl_migrate_data','cl_autologin'),
+            expert=('cl_install_home_crypt_set',),
             hide=('cl_migrate_data',),
             brief=('cl_migrate_user',))
+        dv.addGroup(_("Audio"),
+            normal=('os_audio_default',))
         dv.addGroup(_("Video"),
             normal=('os_install_x11_video_drv','os_install_x11_composite',
                     'os_install_x11_resolution','os_install_fb_resolution',
@@ -399,3 +404,33 @@ class Wsdl:
     @installCatchExcept
     def setup_system_view (self, sid, params):
         return commonView(self,sid,params,"setup_system")
+
+    def setup_audio_vars(self):
+        dv = cl_install.DataVarsInstall()
+        dv.importInstall()
+        dv.flIniFile()
+        dv.Set('cl_action','merge',True)
+        dv.Set('cl_merge_pkg',[None],True)
+        dv.Set('cl_merge_set',"on",True)
+        dv.Set('cl_setup','audio',True)
+        dv.addGroup(None,
+            normal=('os_audio_default',),
+            expert=('cl_templates_locate',"cl_dispatch_conf","cl_verbose_set"),
+            next_label=_("Save"))
+        return dv
+
+    @rpc(Integer, InstallInfo, _returns = Array(ReturnedMessage))
+    @core_method(category=__('Configuration'),title=__('Audio'),
+        image='audio-card',command="cl-setup-audio",
+        gui=True, rights=['setup'])
+    def setup_audio ( self, sid, info):
+        """
+        Setup locale
+        """
+        return self.callMethod(sid,info,logicClass=cl_install.Install,
+                           method="setupSystem",method_name="setup_audio")
+
+    @rpc(Integer, ViewParams,_returns = ViewInfo)
+    @installCatchExcept
+    def setup_audio_view (self, sid, params):
+        return commonView(self,sid,params,"setup_audio")
