@@ -498,7 +498,7 @@ class VariableClAutopartitionScheme(AutopartitionHelper,Variable,AutoPartition):
         if self.Get('os_uefi_set') == 'on':
             return ["uefi","swap","root","data","home"]
         elif self.Get('cl_autopartition_table') == 'gpt':
-            return ["swap","root","data","home","bios"]
+            return ["swap","root","data","home","grub"]
         else:
             return ["swap","root","data","home"]
 
@@ -869,7 +869,7 @@ class VariableClAutopartitionDeviceSize(ReadonlyVariable):
                                  _in=devices))
         # TODO: remove set 10G
         #return str(1024*1024*1024*10)
-        return str(reduce(operator.add,sizeDevice))
+        return str(reduce(operator.add,sizeDevice,0))
 
 class VariableClAutopartitionFreeSize(ReadonlyVariable):
     """
