@@ -20,7 +20,8 @@ from os import path
 import re
 import operator
 from operator import itemgetter
-from calculate.lib.datavars import Variable,VariableError,ReadonlyVariable
+from calculate.lib.datavars import Variable,VariableError,ReadonlyVariable, \
+                                CommonVariableError
 from calculate.lib.utils.common import getSupportArch,getTupleVersion, \
                             cmpVersion
 from calculate.lib.utils.files import readLinesFile, listDirectory
@@ -310,14 +311,28 @@ class VariableClImageFilename(Variable,DistroRepository):
                     distroinfo['os_linux_shortname'],""))
             if subname:
                 subname=" %s"%subname
-            vers = distroinfo['os_linux_build'] or \
+            build = distroinfo['os_linux_build'] or \
                 distroinfo.get('os_linux_ver','')
-            return "{fullname} {os_arch_machine} {ver}".format(
+            ver = distroinfo.get('os_linux_ver','')
+            return "{fullname} {os_arch_machine} {build}".format(
                 fullname="%s%s"%(fullname,subname),filepath=filepath,
-                ver=vers,**distroinfo)
+                build=build,ver=ver,**distroinfo)
         else:
             return filepath
 
+    def humanReadable(self):
+        fullname = self.Get('os_install_linux_name')
+        subname = self.Get('os_install_linux_subname')
+        if subname:
+            subname = " %s"%subname
+        arch = self.Get('os_install_arch_machine')
+        build = self.Get('os_install_linux_build')
+        ver = self.Get('os_install_linux_ver')
+
+        return "{fullname} {ver} {arch} {build}".format(
+                fullname="%s%s"%(fullname,subname),
+                build=build,ver=ver,arch=arch)
+
     def choice(self):
         scratch = self.Get('os_install_scratch')
         rootType = self.Get('os_install_root_type')
@@ -467,7 +482,7 @@ class VariableClTarget(ReadonlyVariable):
         if not systemId or mapDevId.get(disk,'') == systemId:
             systemId = None
         if osInstallScratch:
-            return ScratchPartitionDistributive(disk,mdirectory='/mnt/install',
+            target = ScratchPartitionDistributive(disk,mdirectory='/mnt/install',
                                     check=True,fileSystem=fileSystem,
                                     isFormat=self.isTrue(isFormat),
                                     systemId=systemId,
@@ -486,31 +501,70 @@ class VariableClTarget(ReadonlyVariable):
                                     isFormat=self.isTrue(isFormat),
                                     systemId=systemId,
                                     partitionTable=partTable)
-            multiPartition = None
-            diskData = self.Select(listVars,
-                                   where='os_install_disk_mount',
-                                   ne='/')
-            bindData = self.Select(['os_install_bind_path',
-                                    'os_install_bind_mountpoint'],
-                                    where='os_install_bind_mountpoint',
-                                    ne='')
-            if diskData or bindData:
-                multiPartition = MultiPartitions()
-                target.multipartition = multiPartition
-            for disk,mount,fileSystem,isFormat,partTable,systemId in diskData:
-                if not systemId or mapDevId.get(disk,'') == systemId:
-                    systemId = None
-                multiPartition.addPartition(dev=disk,
-                    mountPoint=mount,
-                    fileSystem=fileSystem,
-                    isFormat=self.isTrue(isFormat),
-                    systemId=systemId,
-                    partitionTable=partTable)
-            for source,dest in bindData:
-                multiPartition.addPartition(dev=source,
-                    mountPoint=dest,
-                    fileSystem='bind',
-                    isFormat=False,
-                    systemId=None,
-                    partitionTable='')
-            return target
+        multiPartition = None
+        diskData = self.Select(listVars,
+                               where='os_install_disk_mount',
+                               ne='/')
+        bindData = self.Select(['os_install_bind_path',
+                                'os_install_bind_mountpoint'],
+                                where='os_install_bind_mountpoint',
+                                ne='')
+        if diskData or bindData:
+            multiPartition = MultiPartitions()
+            target.multipartition = multiPartition
+        for disk,mount,fileSystem,isFormat,partTable,systemId in diskData:
+            if not systemId or mapDevId.get(disk,'') == systemId:
+                systemId = None
+            multiPartition.addPartition(dev=disk,
+                mountPoint=mount,
+                fileSystem=fileSystem,
+                isFormat=self.isTrue(isFormat),
+                systemId=systemId,
+                partitionTable=partTable)
+        for source,dest in bindData:
+            multiPartition.addPartition(dev=source,
+                mountPoint=dest,
+                fileSystem='bind',
+                isFormat=False,
+                systemId=None,
+                partitionTable='')
+        return target
+
+class VariableClImageNewOnly(Variable):
+    """
+    Distributive image filename
+    """
+    type = 'bool'
+    opt = ['-U','--update']
+    value = "off"
+
+    def init(self):
+        self.label = _("Install newer images only")
+        self.help = _("install newer images only")
+        
+    def installedBuild(self):
+        """
+        Get build already installed system
+        Need for check update
+        """
+        imageData = None
+        rootDev = self.Get('os_install_root_dev')
+        if not rootDev:
+            return ""
+        try:
+            imageData = Distributive().getInfo(rootDev)
+            return imageData.get('os_linux_build','')
+        except:
+            pass
+        return ""
+
+    def check(self,value):
+        if value == 'on':
+            try:
+                imageData = Distributive().getInfo(self.Get('cl_image_filename'))
+            except Exception as e:
+                raise VariableError(_("Wrong image file"))
+            if imageData.get('os_linux_build','') <= \
+                self.Get('os_linux_build') or \
+                imageData.get('os_linux_build','') <= self.installedBuild():
+                raise CommonVariableError(_("The image for update not found"))
