@@ -213,7 +213,8 @@ class VariableOsInstallClockTimezone(LocaleVariable):
                 "Atlantic/Azores", "Atlantic/Cape_Verde", "UTC",
                 "Africa/Casablanca", "Europe/Amsterdam", "Europe/Belgrade",
                 "Europe/Brussels", "Europe/Zagreb", "Africa/Tunis",
-                "Asia/Amman", "Europe/Istanbul", "Asia/Beirut", "Europe/Kiev",
+                "Asia/Amman", "Europe/Istanbul", "Asia/Beirut",
+                "Europe/Helsinki", "Europe/Kiev",
                 "Africa/Windhoek", "Asia/Jerusalem", "Africa/Cairo",
                 "Europe/Minsk", "Africa/Harare", "Asia/Baghdad", "Asia/Kuwait",
                 "Europe/Moscow", "Africa/Nairobi", "Asia/Tbilisi",
