@@ -28,11 +28,13 @@ from calculate.lib.utils.ip import (getInterfaces,getIp,getMask,getMac,
     cidrToMask,maskToCidr,getIpNet,isDhcpIp,checkIp,checkMask,
     getOperState)
 from calculate.lib.utils.device import lspci
-from calculate.lib.utils.files import listDirectory,readLinesFile,process
+from calculate.lib.utils.files import listDirectory,readLinesFile,process,\
+                                      readFile
 from calculate.lib.utils import ip
 from calculate.lib.utils.portage import isPkgInstalled
 from operator import itemgetter
 from itertools import *
+import hashlib
 
 class NetHelper:
     """
@@ -95,8 +97,12 @@ class VariableOsInstallNetInterfacesOrig(NetHelper,ReadonlyVariable):
             'etc/udev/rules.d/70-persistent-net.rules')
         pathNewUdevNet = path.join(chrootPath,
             'etc/udev/rules.d/80-net-name-slot.rules')
-        for foundPath in ifilter(path.exists,(pathOldUdevNet,
-                                              pathNewUdevNet)):
+        pathOrigUdevNet = path.join(chrootPath,
+            'lib/udev/rules.d/80-net-name-slot.rules')
+        if path.exists(pathOldUdevNet) or \
+            (path.exists(pathNewUdevNet) and 
+            hashlib.md5(readFile(pathNewUdevNet)).digest() != \
+            hashlib.md5(readFile(pathOrigUdevNet)).digest()):
             return self.Get('os_install_net_interfaces')
         def getOrig(x):
             try:
