@@ -19,7 +19,8 @@ import sys
 import re
 from os import path
 from calculate.lib.datavars import Variable,VariableError,ReadonlyVariable, \
-                                   TableVariable,PasswordError
+                                   TableVariable,PasswordError, \
+                                   ReadonlyTableVariable,FieldValue
 from calculate.install.fs_manager import FileSystemManager
 from calculate.lib.utils.files import (readFile,getProgPath,process,
     readLinesFile)
@@ -163,6 +164,15 @@ class VariableClMigrateRootPwd(UserHelper,Variable):
         if not value:
             raise PasswordError(_("Password for user %s missing")%"root")
 
+class VariableClInstallHomeCryptSet(UserHelper,Variable):
+    type = 'bool'
+    opt = ["--crypt-home","-C"]
+    untrusted = True
+
+    def init(self):
+        self.help = _("crypt user profiles")
+        self.label = _("Crypt user profiles")
+
 class VariableClMigrateData(UserHelper,TableVariable):
     """
     User migrate data table
@@ -509,13 +519,14 @@ class VariableClSetup(Variable):
     value = ""
 
     def choice(self):
-        return ["network","locale","video","boot","users",""]
+        return ["audio","network","locale","video","boot","users",""]
 
     def humanReadable(self):
         mapType = {'network':_("network settings"),
                    'locale':_("localization and time options"),
                    'video':_("video settings"),
                    'boot':_("boot parameters"),
+                   'audio':_("audio parameters"),
                    'users':_("user settings") }
         return mapType.get(self.Get(),"")
 
@@ -650,3 +661,95 @@ class VariableOsInstallGrubTerminal(Variable):
 
     def choice(self):
         return ['gfxterm','console']
+
+    def uncompatible(self):
+        """
+        Grub setting up unavailable for flash installation
+        """
+        if self.Get('os_install_root_type') == 'flash':
+            return _("Grub configuration unavailable for Flash install")
+        return ""
+
+class VariableOsAudioData(ReadonlyTableVariable):
+    """
+    Information about audio cards
+    """
+    source = ['os_audio_id',
+              'os_audio_name']
+
+    def get(self,hr=False):
+        """LVM hash"""
+        aplay = getProgPath('/usr/bin/aplay')
+        if not aplay:
+            return [[]]
+        entry = re.compile('^card (\d+): ([^,]+)')
+        return tuple(map(lambda x:x.groups(),
+               filter(None,map(entry.search,
+               process(aplay,'-l')))))
+
+    setValue = Variable.setValue
+
+class VariableOsAudioId(FieldValue,ReadonlyVariable):
+    """
+    Order Id of audio card
+    """
+    type = "list"
+    source_variable = "os_audio_data"
+    column = 0
+
+class VariableOsAudioName(FieldValue,ReadonlyVariable):
+    """
+    Name of audio card
+    """
+    type = "list"
+    source_variable = "os_audio_data"
+    column = 1
+
+class VariableOsAudioDefaultSet(ReadonlyVariable):
+    """
+    Force write in config 0
+    """
+    type = "bool"
+
+    def get(self):
+        res = self.Select('os_audio_id',where='os_audio_name',
+                              notlike='HDMI',limit=1)
+        audioDefault = self.Get('os_audio_default')
+        if audioDefault != '0' or \
+            res and res != "0" and audioDefault == '0':
+            return 'on'
+        return 'off'
+
+class VariableOsAudioDefault(Variable):
+    """
+    Current default audio card
+    """
+    type  = "choice"
+    opt = ['--audio']
+
+    def init(self):
+        self.label = _("Default audio card")
+        self.help = _("set default audio card")
+
+    def get(self):
+        defaultCardRe = re.compile('defaults.ctl.card\s+(\d+)')
+        entry = defaultCardRe.search(readFile('/etc/asound.conf'))
+        if entry and entry.groups()[0] in self.Get('os_audio_id'):
+            return entry.groups()[0]
+        res = self.Select('os_audio_id',where='os_audio_name',
+                          notlike='HDMI',limit=1)
+        return res or '0'
+
+    def choice(self):
+        data = self.Get('os_audio_data')
+        if data and data[0]:
+            return self.Get('os_audio_data')
+        return []
+
+    def uncompatible(self):
+        """
+        Audio setting up unavailable for flash installation
+        """
+        if self.Get('os_install_root_type') == 'flash':
+            return _("Audio configuration unavailable for Flash install")
+        return ""
